import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { SubscriptionPolicy } from "../operationsInterfaces";
import { SubscriptionClient } from "../subscriptionClient";
import { GetTenantPolicyResponse, SubscriptionPolicyListPolicyForTenantOptionalParams, PutTenantPolicyRequestProperties, SubscriptionPolicyAddUpdatePolicyForTenantOptionalParams, SubscriptionPolicyAddUpdatePolicyForTenantResponse, SubscriptionPolicyGetPolicyForTenantOptionalParams, SubscriptionPolicyGetPolicyForTenantResponse } from "../models";
/** Class containing SubscriptionPolicy operations. */
export declare class SubscriptionPolicyImpl implements SubscriptionPolicy {
    private readonly client;
    /**
     * Initialize a new instance of the class SubscriptionPolicy class.
     * @param client Reference to the service client
     */
    constructor(client: SubscriptionClient);
    /**
     * Get the subscription tenant policy for the user's tenant.
     * @param options The options parameters.
     */
    listPolicyForTenant(options?: SubscriptionPolicyListPolicyForTenantOptionalParams): PagedAsyncIterableIterator<GetTenantPolicyResponse>;
    private listPolicyForTenantPagingPage;
    private listPolicyForTenantPagingAll;
    /**
     * Create or Update Subscription tenant policy for user's tenant.
     * @param body Put tenant policy request properties.
     * @param options The options parameters.
     */
    addUpdatePolicyForTenant(body: PutTenantPolicyRequestProperties, options?: SubscriptionPolicyAddUpdatePolicyForTenantOptionalParams): Promise<SubscriptionPolicyAddUpdatePolicyForTenantResponse>;
    /**
     * Get the subscription tenant policy for the user's tenant.
     * @param options The options parameters.
     */
    getPolicyForTenant(options?: SubscriptionPolicyGetPolicyForTenantOptionalParams): Promise<SubscriptionPolicyGetPolicyForTenantResponse>;
    /**
     * Get the subscription tenant policy for the user's tenant.
     * @param options The options parameters.
     */
    private _listPolicyForTenant;
    /**
     * ListPolicyForTenantNext
     * @param nextLink The nextLink from the previous successful call to the ListPolicyForTenant method.
     * @param options The options parameters.
     */
    private _listPolicyForTenantNext;
}
//# sourceMappingURL=subscriptionPolicy.d.ts.map